Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2299)

Unified Diff: content/public/browser/posix_file_descriptor_info.h

Issue 2950153002: Improve process launch handle sharing API. (Closed)
Patch Set: Merge Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/file_descriptor_info.h ('k') | content/shell/browser/shell_content_browser_client.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/posix_file_descriptor_info.h
diff --git a/content/public/browser/file_descriptor_info.h b/content/public/browser/posix_file_descriptor_info.h
similarity index 73%
rename from content/public/browser/file_descriptor_info.h
rename to content/public/browser/posix_file_descriptor_info.h
index ef44a083926f4caf2b09c766bda436a6fa7fa47d..07e61cf85f32bbb78243402d8b87d29d072412ee 100644
--- a/content/public/browser/file_descriptor_info.h
+++ b/content/public/browser/posix_file_descriptor_info.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CONTENT_PUBLIC_BROWSER_FILE_DESCRIPTOR_INFO_H_
-#define CONTENT_PUBLIC_BROWSER_FILE_DESCRIPTOR_INFO_H_
+#ifndef CONTENT_PUBLIC_BROWSER_POSIX_FILE_DESCRIPTOR_INFO_H_
+#define CONTENT_PUBLIC_BROWSER_POSIX_FILE_DESCRIPTOR_INFO_H_
#include <stddef.h>
@@ -15,14 +15,15 @@
namespace content {
// FileDescriptorInfo is a collection of file descriptors which is needed to
// launch a process. You should tell FileDescriptorInfo which FDs should be
// closed and which shouldn't so that it can take care of the lifetime of FDs.
//
// See base/process/launcher.h for more details about launching a process.
-class FileDescriptorInfo {
+class PosixFileDescriptorInfo {
public:
- virtual ~FileDescriptorInfo() {}
+ virtual ~PosixFileDescriptorInfo() {}
// Adds an FD associated with an ID, without delegating the ownerhip of ID.
virtual void Share(int id, base::PlatformFile fd) = 0;
@@ -43,8 +44,8 @@ class FileDescriptorInfo {
// A GetMapping() variant that adjusts the ID value by |delta|.
// Some environments need this trick.
- virtual std::unique_ptr<base::FileHandleMappingVector>
- GetMappingWithIDAdjustment(int delta) const = 0;
+ virtual base::FileHandleMappingVector GetMappingWithIDAdjustment(
+ int delta) const = 0;
// API for iterating over the registered ID-FD pairs.
virtual base::PlatformFile GetFDAt(size_t i) const = 0;
@@ -58,6 +59,6 @@ class FileDescriptorInfo {
virtual base::ScopedFD ReleaseFD(base::PlatformFile file) = 0;
};
-}
+} // namespace content
-#endif // CONTENT_PUBLIC_BROWSER_FILE_DESCRIPTOR_INFO_H_
+#endif // CONTENT_PUBLIC_BROWSER_POSIX_FILE_DESCRIPTOR_INFO_H_
« no previous file with comments | « content/public/browser/file_descriptor_info.h ('k') | content/shell/browser/shell_content_browser_client.h » ('j') | no next file with comments »

Powered by Google App Engine
@@ -15,14 +15,15 @@
namespace content {
-// FileDescriptorInfo is a collection of file descriptors which is needed to
-// launch a process. You should tell FileDescriptorInfo which FDs should be
-// closed and which shouldn't so that it can take care of the lifetime of FDs.
+// PoxisFileDescriptorInfo is a collection of file descriptors which is needed
+// to launch a process. You should tell PosixFileDescriptorInfo which FDs
+// should be closed and which shouldn't so that it can take care of the
+// lifetime of FDs.
//
// See base/process/launcher.h for more details about launching a process.
This is Rietveld 408576698